program read_srb_rel3_longwave_3hrly_nc
use netcdf
implicit none

character (200) :: path_in, file_in, file_out
integer :: out_lat, out_lon
integer :: rec, index
integer :: month, year
integer :: ndmn(12)=(/31,28,31,30,31,30,31,31,30,    &
                                         31,30,31/)
character(4) :: cyear
character(2) :: cmon

! netCDF id
integer :: ncid
! dimension ids
integer :: lat_dim, lon_dim, time_dim

integer, parameter :: NDIMS = 3
integer, parameter :: NLVLS = 1, NLATS = 180, NLONS = 360
character (len = *), parameter :: LAT_NAME = "lat"
character (len = *), parameter :: LON_NAME = "lon"
character (len = *), parameter :: time_name = "time"
integer :: NRECS 

! The start and count arrays will tell the netCDF library where to
! read our data.
integer :: start(NDIMS), count(NDIMS)

! In addition to the latitude and longitude dimensions, we will also
! create latitude and longitude variables which will hold the actual
! latitudes and longitudes. Since they hold data about the
! coordinate system, the netCDF term for these is: "coordinate
! variables."

real :: lats(NLATS), lons(NLONS)

character (len = *), parameter :: ctoaup_name="clr_lw_toa_up"
character (len = *), parameter :: csfcup_name="clr_lw_sfc_up"
character (len = *), parameter :: csfcdn_name="clr_lw_sfc_dn"
character (len = *), parameter :: toaup_name="lw_toa_up"
character (len = *), parameter :: sfcup_name="lw_sfc_up"
character (len = *), parameter :: sfcdn_name="lw_sfc_dn"
character (len = *), parameter :: daynight_name="day_night_flag"

! variable ids
integer :: lat_id,  lon_id,  time_id,  clr_lw_toa_up_id,  clr_lw_sfc_up_id, &
           clr_lw_sfc_dn_id, lw_toa_up_id, lw_sfc_up_id, lw_sfc_dn_id, &
           day_night_flag_id

double precision :: time

real, dimension(nlons,nlats) :: clr_lw_toa_up,  clr_lw_sfc_up, &
           clr_lw_sfc_dn, lw_toa_up, lw_sfc_up, lw_sfc_dn,&
           day_night_flag

integer :: dimids(NDIMS)

! To check the units attributes.
character (80) :: clr_lw_toa_up_units_in,  clr_lw_sfc_up_units_in, &
           clr_lw_sfc_dn_units_in, lw_toa_up_units_in, lw_sfc_up_units_in, &
           lw_sfc_dn_units_in, day_night_flag_units_in
character (80) :: lat_units_in, lon_units_in

! To get the scale factors.
real :: clr_lw_toa_up_scale_in,  clr_lw_sfc_up_scale_in, &
           clr_lw_sfc_dn_scale_in, lw_toa_up_scale_in, lw_sfc_up_scale_in, &
           lw_sfc_dn_scale_in, day_night_flag_scale_in

month=2
year=1984
write (cyear,"(i4)") year
write (cmon,"(i2.2)") month
NRECS=ndmn(month)
if (month.eq.2.and.mod(year,4).eq.0) NRECS=ndmn(month)+1
NRECS=NRECS*8

path_in=''
path_in='/Volumes/RADAPP/srb/NetCDF/GLW/1984/'
file_in=trim(path_in)//'srb_rel3.1_longwave_3hrly_'//cyear//cmon//'.nc'
print*,trim(file_in)

! Open the file.
call check( nf90_open(file_in, nf90_nowrite, ncid))

! Get the varids of the latitude and longitude coordinate variables.
call check( nf90_inq_varid(ncid, LAT_NAME, lat_id) )
call check( nf90_inq_varid(ncid, LON_NAME, lon_id) )

! Read the latitude and longitude data.
call check( nf90_get_var(ncid, lat_id, lats) )
call check( nf90_get_var(ncid, lon_id, lons) )

! Read the time information.
call check( nf90_inq_varid(ncid, time_name, time_id) )
call check( nf90_get_var(ncid, time_id, time) )

! Get the varids of the variables
call check( nf90_inq_varid(ncid, daynight_name, day_night_flag_id) )
call check( nf90_inq_varid(ncid, ctoaup_name, clr_lw_toa_up_id) )
call check( nf90_inq_varid(ncid, csfcup_name, clr_lw_sfc_up_id) )
call check( nf90_inq_varid(ncid, csfcdn_name, clr_lw_sfc_dn_id) )
call check( nf90_inq_varid(ncid, toaup_name, lw_toa_up_id) )
call check( nf90_inq_varid(ncid, sfcup_name, lw_sfc_up_id) )
call check( nf90_inq_varid(ncid, sfcdn_name, lw_sfc_dn_id) )

! Read the units
call check( nf90_get_att(ncid, day_night_flag_id, 'units', day_night_flag_units_in) )
call check( nf90_get_att(ncid, clr_lw_toa_up_id, 'units', clr_lw_toa_up_units_in) )
call check( nf90_get_att(ncid, clr_lw_sfc_up_id, 'units', clr_lw_sfc_up_units_in) )
call check( nf90_get_att(ncid, clr_lw_sfc_dn_id, 'units', clr_lw_sfc_dn_units_in) )
call check( nf90_get_att(ncid, lw_toa_up_id, 'units', lw_toa_up_units_in) )
call check( nf90_get_att(ncid, lw_sfc_up_id, 'units', lw_sfc_up_units_in) )
call check( nf90_get_att(ncid, lw_sfc_dn_id, 'units', lw_sfc_dn_units_in) )

! Read the scale factors
call check( nf90_get_att(ncid, day_night_flag_id, 'scale_factor', day_night_flag_scale_in) )
call check( nf90_get_att(ncid, clr_lw_toa_up_id, 'scale_factor', clr_lw_toa_up_scale_in) )
call check( nf90_get_att(ncid, clr_lw_sfc_up_id, 'scale_factor', clr_lw_sfc_up_scale_in) )
call check( nf90_get_att(ncid, clr_lw_sfc_dn_id, 'scale_factor', clr_lw_sfc_dn_scale_in) )
call check( nf90_get_att(ncid, lw_toa_up_id, 'scale_factor', lw_toa_up_scale_in) )
call check( nf90_get_att(ncid, lw_sfc_up_id, 'scale_factor', lw_sfc_up_scale_in) )
call check( nf90_get_att(ncid, lw_sfc_dn_id, 'scale_factor', lw_sfc_dn_scale_in) )

count = (/ NLONS, NLATS, 1 /)
start = (/ 1, 1, 1 /)

! Read the variables & adjust for scale factor
do rec = 1, NRECS
   start(3)=rec

   call check( nf90_get_var(ncid, day_night_flag_id, day_night_flag,start=start,&
       count=count) )
   day_night_flag=day_night_flag*day_night_flag_scale_in

   call check( nf90_get_var(ncid, clr_lw_toa_up_id, clr_lw_toa_up,start=start,&
       count=count) )
   clr_lw_toa_up=clr_lw_toa_up*clr_lw_toa_up_scale_in

   call check( nf90_get_var(ncid, clr_lw_sfc_up_id, clr_lw_sfc_up,start=start,&
       count=count) )
   clr_lw_sfc_up=clr_lw_sfc_up*clr_lw_sfc_up_scale_in

   call check( nf90_get_var(ncid, clr_lw_sfc_dn_id, clr_lw_sfc_dn,start=start,&
       count=count) )
   clr_lw_sfc_dn=clr_lw_sfc_dn*clr_lw_sfc_dn_scale_in

   call check( nf90_get_var(ncid, lw_toa_up_id, lw_toa_up,start=start,&
       count=count) )
   lw_toa_up=lw_toa_up*lw_toa_up_scale_in

   call check( nf90_get_var(ncid, lw_sfc_up_id, lw_sfc_up,start=start,&
       count=count) )
   lw_sfc_up=lw_sfc_up*lw_sfc_up_scale_in

   call check( nf90_get_var(ncid, lw_sfc_dn_id, lw_sfc_dn,start=start,&
       count=count) )
   lw_sfc_dn=lw_sfc_dn*lw_sfc_dn_scale_in

!  Sample flux out to screen
   if (rec==5) then
     write(*,*) 'Sample OLR for Hour rec = ', rec
     write(*,"(10x,10f10.2)") (lons(out_lon),out_lon=22,31)
     do out_lat=55,45,-1
        write(*,"(11f10.2)") lats(out_lat),(lw_toa_up(out_lon,out_lat),out_lon=22,31)
     end do
   end if

end do

call check( nf90_close(ncid) )

contains
!*****************************************
  subroutine check(status)
    integer, intent ( in) :: status

    if(status /= nf90_noerr) then
      print *, trim(nf90_strerror(status))
      stop "Stopped"
    end if
  end subroutine check
!*****************************************

end program read_srb_rel3_longwave_3hrly_nc
